=================================================================
``psyclone.domain.gocean.transformations.gocean_loop_fuse_trans``
=================================================================

.. automodule:: psyclone.domain.gocean.transformations.gocean_loop_fuse_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.gocean.transformations.gocean_loop_fuse_trans


Classes
=======

- :py:class:`GOceanLoopFuseTrans`:
  GOcean API specialisation of the :py:class:`base class <LoopFuseTrans>`


.. autoclass:: GOceanLoopFuseTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: GOceanLoopFuseTrans
      :parts: 1
